@@ -1,8 +1,10 @@
-use super::list::ListFormat;
 use std::{rc::Rc, sync::Arc};
+
 use swc_common::{errors::SourceMapper, BytePos, SourceMap, SourceMapperDyn, Span, Spanned};
 use swc_ecma_ast::*;
 
+use super::list::ListFormat;
+
 pub trait SpanExt: Spanned {
     #[inline]
     fn is_synthesized(&self) -> bool {
@@ -289,7 +291,8 @@ impl StartsWithAlphaNum for Expr {
             Expr::TsTypeAssertion(..) => false,
             Expr::TsNonNull(TsNonNullExpr { ref expr, .. })
             | Expr::TsAs(TsAsExpr { ref expr, .. })
-            | Expr::TsConstAssertion(TsConstAssertion { ref expr, .. }) => {
+            | Expr::TsConstAssertion(TsConstAssertion { ref expr, .. })
+            | Expr::TsInstantiation(TsExprWithTypeArgs { ref expr, .. }) => {
                 expr.starts_with_alpha_num()
             }
 
